==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/Compliance.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.FipsEnum;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Compliance
 */
@JsonPropertyOrder({ Compliance.JSON_PROPERTY_FIPS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class Compliance implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_FIPS = "fips";
    private FipsEnum fips;

    public Compliance() {
    }

    public Compliance fips(FipsEnum fips) {

        this.fips = fips;
        return this;
    }

    /**
     * Get fips
     *
     * @return fips
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_FIPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public FipsEnum getFips() {
        return fips;
    }

    @JsonProperty(JSON_PROPERTY_FIPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFips(FipsEnum fips) {
        this.fips = fips;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Compliance compliance = (Compliance) o;
        return Objects.equals(this.fips, compliance.fips);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(fips);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class Compliance {\n");
        sb.append("    fips: ").append(toIndentedString(fips)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/Compliance.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.FipsEnum;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Compliance
 */
@JsonPropertyOrder({ Compliance.JSON_PROPERTY_FIPS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class Compliance implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_FIPS = "fips";
    private FipsEnum fips;

    public Compliance() {
    }

    public Compliance fips(FipsEnum fips) {

        this.fips = fips;
        return this;
    }

    /**
     * Get fips
     *
     * @return fips
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_FIPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public FipsEnum getFips() {
        return fips;
    }

    @JsonProperty(JSON_PROPERTY_FIPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFips(FipsEnum fips) {
        this.fips = fips;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Compliance compliance = (Compliance) o;
        return Objects.equals(this.fips, compliance.fips);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(fips);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class Compliance {\n");
        sb.append("    fips: ").append(toIndentedString(fips)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
